﻿# The script of the game goes in this file.

# Set up LayeredImage Sprites
layeredimage steven:
    always "steven_base"
    group face auto:
        attribute neutral default

layeredimage bob:
    always "bob_base"
    group face auto:
        attribute neutral default

layeredimage dee:
    always "dee_base"
    group face auto:
        attribute neutral default

layeredimage ethan:
    always "ethan_base"
    group face auto:
        attribute neutral default

image poo = "emojipoo-shocked"

# Declare characters used by this game. The color argument colorizes the
# name of the character.

define s = Character("Steven")
define s_nvl = Character("Steven", kind=nvl)
define nar_nvl = nvl_narrator
define b = Character("Bob")
define d = Character("Dee")
define e = Character("Ethan")
define p = Character("Poo")

## Splashscreen ############################################################
## A portion of the game that plays at launch, before the main menu is shown.
## https://www.renpy.org/doc/html/splashscreen_presplash.html

label splashscreen:

    scene black

    ## The first time the game is launched, players can set their accessibility settings.
    if not persistent.firstlaunch:

        ## This screen is at the top of extras.rpy

        call screen splash_settings

        ## This screen will not appear in subsequent launches of the game when
        ## the following variable becomes true.
        $ persistent.firstlaunch = True

    return

## The game starts here.

label start:

    # Show a background. This uses a placeholder by default, but you can
    # add a file (named either "bg room.png" or "bg room.jpg") to the
    # images directory to show it.

    $ play_music(OST_At_Home)

    scene kitchen1

    # This shows a character sprite.

    show steven neutral at center:

        ## Sprite generated by Mannequin are fullbody, so we do need to
        ## move steven down slightly so she's not floating about.
        yoffset 250

    # Placing the effect after both image statements will apply said
    # effect on both images.
    with fade

    # Set some defaults that we need later on.
    $ outdoor_poop = False
    $ antagonize_dee = False

    # Allows for simpler logic elsewhere
    $ keep_music = False


    # This unlocks the the achievement with the corresponding name
    $ achievement.grant("Finished work day.")

    s "There's only one solution to what I'm feeling."

    s "I need a cup of juice with a healthy dose of Polyethelyne Glycol, the active ingrediant in all the popular laxitives."

    menu:
        "Drink it.":
            s "Now I just need to wait."
            $ laxed_up = True
            jump drink_over
        "Don't drink it.":
            s "Maybe it will work itself out."
            $ laxed_up = False
            jump drink_over

label drink_over:

    show bob at right:
        yoffset 350

    "The phone rings. It is my boss."

    menu:
        "Answer it.":
            jump boss_on_phone

        "Ignore it.":
            jump boss_fired_by_text

label boss_fired_by_text:

    hide bob

    b "(Text message) You ditched my party and ignored my call?"

    $ achievement.grant("Fired by text message.")

    b "(Text message) You're fired."

    s_nvl "I guess there's no risk of pooping myself in front of my boss, if I no longer have a boss."
    s_nvl "Maybe I should try for strictly telecommuting at my next job."
    nar_nvl "Bad ending: Fired by text message."

    jump credits

label boss_on_phone:

    show bob at right:
        yoffset 250

    b "Hey! I saw you didn't confirm for the party tonight."

    s "Wait, that was tonight?"

    b "It's a mandatory company event, so there will be problems if you skip out."

    s "When does it start?"

    b "It starts in about 5 minutes. Fortunately, you're on this side of town, aren't you?"

    s "... Yeah. I guess I am. I'll be right there."

    hide bob

    show steven neutral with dissolve:
        yoffset 250

label scene_front_of_house:
    scene the_jp_mansion_day

    $ play_music(OST_Outside_Boss_House,fadeout=2.0)

    if not laxed_up:
        "The drive was quick and uneventful."
        jump calmly_enter_house

    show steven neutral with dissolve:
        yoffset 250

    s "Maybe it is stress, but I really need to poop, like right now."

    menu:
        "Find a spot to poop outside.":
            $ outdoor_poop = True
            jump outdoor_pooping
        "There's a bathroom inside. I just need to hurry.":
            $ outdoor_poop = False
            jump worriedly_enter_house

label outdoor_pooping:
    "I find a spot out of the way."
    "I've never pooped outside before. I thought I'd be self-conscious, but I really needed to go."

    $ achievement.grant("No bathroom. No problem.")
    show poo at right with easeinbottom:
        yoffset 75
    ic "The Poo has arrived."

    "There were leaves nearby to use to wipe, but it isn't nearly as clean as a bathroom."

    jump calmly_enter_house

label worriedly_enter_house:

    show steven neutral at center with move:
        yoffset 250

    "It seems I'm not the only one arriving now."

    show poo at center behind steven with easeinbottom:
        xoffset -100
        yoffset 150
    ic "The Poo hides behind Steven, low to the ground."

    "One of the three people arriving before me is taking a long time to enter."

    show poo at center with move:
        xoffset -100
        yoffset 75

    ic "The Poo raises from the ground."

    "Eventually, I excuse myself to the bathroom."
    $ play_music(OST_Party)
    jump bathroom_line

label calmly_enter_house:
    "We engage pleasantries for a few minutes before heading inside."

    # $ play_music(OST_Party, fadein=2.0, fadeout=2.0)
    $ play_music(OST_Party)

    scene kitchen1_daylight

    show steven neutral at center:
        yoffset 250

    if outdoor_poop:
        show poo at center behind steven:
            xoffset -100
            yoffset 150

    with fade

    if outdoor_poop:
        "I'm pretty sure that's not dirt smearing my hand. Unfortunately, there's a line to the bathroom."

        s "I think I have something on my hands. I'm going to wash them before I get any snacks."

        "Someone says, \"Sure!\""

    show dee neutral at left with easeinleft:
        yoffset 250
    ic "An unknown teenager arrives in a sour mood."

    if outdoor_poop:
        "???" "You stink. Did you step in poop outside or something?"

        p "(I think she means me. You can smell me, can't you Steven?)"

        "I lift up each of my shoes to check. I might have gotten some poop on them. It was a new experience for me."

        s "Nope. I don't think it is me."
    else:
        "I pass gas. I manage to be silent, but it is a real stinker."

        "???" "You stink. Could you go outside before you fart like that?"

        show steven upset

        "I look around in confusion."

        s "Nope. I don't think it was me."

    show ethan at right with easeinright:
        yoffset 250
    ic "A new person arrives."

    e "I'm Ethan, they/them. I see you've met our daughter Dee, or didn't she introduce herself?"

    d "(She turns to Ethan.) Fine, Mapa."

    d "(She turns back to me.) I'm Dee, she/her. I like things that smell nice."

    "That seemed rather pointed."

    e "Is Dee giving you a hard time? She's a good girl, but she doesn't seem to enjoy her father's work parties."

    menu:
        "She said I smelled bad.":
            $ antagonize_dee = True
            d "Mapa, he's stinking up our house!"
        "She just seems like a teenager.":
            $ antagonize_dee = False
            d "Well, duh."
    hide dee
    ic "Dee departs to another room."

    menu:
        "Go to the bathroom to check.":
            jump bathroom_line
        "Eat some snacks.":
            pass

    "Wait. What was in those snacks?"

    if outdoor_poop:
        p "(Wee! I've got friends coming! Better move quick!)"
    else:
        show poo at center behind steven:
            xoffset -100
            yoffset 200
        ic "The Poo is present."
        p "(I'm coming whether you like it or not! Better hustle!)"

    show bob at left with easeinleft:
        yoffset 250
    ic "Bob joins his spouse, Ethan."

    if outdoor_poop:
        b "So, Steven... My daughter just told me you should go home because you had a poop accident."
    else:
        b "So, Steven... My daughter says you're over here stinking up the place. \"Farting up a storm,\" were her exact words."

    show steven upset
    "I can't hold it any longer."
    ic "Steven looks upset."

    menu:
        "Escape. Run away. Never come back.":
            jump poo_accident1
        "Try harder not to poop.":
            pass

    show poo at center:
        xoffset 0
    show steven shocked behind poo
    ic "Steven looks shocked, as the Poo is in front of him."

    p "(Hello my friends! Welcome!)"
    show poo at center:
        yoffset 75
    ic "The Poo raises to prominence."

    p "(Hey! I guess there's not room for everybody...)"

    show bob angry
    ic "Bob looks angry."

    b "Did you just poop yourself?"

    s "I... well..."

    b "Don't lie. It's fallen down your pant leg. I see it on your shoe!"

    b "You need to leave here right now! And don't come back to work, either!"

    $ achievement.grant("In front of the boss.")

    s_nvl "What a way to make a lasting impression."
    s_nvl "I heard they tried pet cleaner on the rug, but they had to just throw the whole thing out."
    s_nvl "At least it was a throw rug."
    nar_nvl "Bad ending: Poop accident in front of boss."

    jump credits


label poo_accident1:
    $ achievement.grant("Too embarrassed to work.")

    s_nvl "The poop was flowing even while I ran to my car."
    s_nvl "Did anyone notice? It didn't matter. I couldn't face seeing any of them again."
    s_nvl "I didn't even bother returning to clean out my desk."
    nar_nvl "Bad ending: Quit from embarrassment."

    jump credits

label bathroom_line:
    scene living_room1
    show steven neutral at left:
        yoffset 250
    show dee neutral at right:
        yoffset 250

    show poo at left behind steven:
        xoffset -100
        yoffset 200

    with fade
    "There's a line at the bathroom. I wait in the living room."

    if laxed_up:
        d "You just now figured out where the bathroom was?"
    if outdoor_poop:
        d "I figure you've probably needed to go for a while."
    else:
        if laxed_up:
            d "You look like you really need to go."
        else:
            d "Are you constipated, or no longer constipated? I can't tell."
        d "Maybe my dad just has that effect on people."
    if antagonize_dee:
        d "You better get comfortable. I'm going to be a while."
    else:
        d "I just need to pee, so I'll be quick."

    "Someone leaves the bathroom laughing to themself and shaking their head. Dee enters."
    hide dee
    "I scoot up against a wall so someone can walk past me."
    "I pass gas. It is both audible and stinky."
    show bob neutral at right:
        yoffset 250
    ic "Bob arrives."
    b "I heard that in the other room. Goodness, that's one dog with a bite even worse than its bark!"
    show poo behind steven:
        xoffset -100
        yoffset 75
    ic "The Poo is present behind Steven."
    if laxed_up:
        p "(I want to bring my friends to this party.)"
        if outdoor_poop:
            "It still isn't as bad as when I arrived."
    else:
        p "(When is the party starting? I want to get moving!)"
    if not antagonize_dee:
        jump bathroom
    jump poo_accident2

label poo_accident2:
    "I stare at the bathroom door and try to disappear against the wall."
    b "Did you understand that memo about the plans for the next fiscal quarter? See, ..."
    show poo:
        yoffset 75
    "I try to focus on not pooping."
    show steven behind poo
    ic "The Poo is now in front of Steven."
    p "(I'm still here... and I'm bringing some friends!)"
    "I fail."

    s_nvl "I thought it would be okay. There was an accident, but then the bathroom opened up."
    s_nvl "Unfortunately, as I stepped away from the wall I had been pressed up against, Bob noticed that it had a new stain."
    s_nvl "I made a mess of their bathroom trying to clean myself up, only to exit the bathroom and get fired anyway."
    $ achievement.grant("Stained a wall.")
    nar_nvl "Bad ending: Pooped in a hallway."

    jump credits

label bathroom:
    scene bath3

    show steven neutral at center:
        yoffset 250
    with fade

    "I'm just glad I got to the bathroom in time."
    $ play_music(When_You_Leave)
    "A man starts singing an acapella song about pooping."

    s "What? Is someone in here with me?"

    "It's probably a gag. I need to finish up first."

    if outdoor_poop:
        "I had some stuff to clean up, but nothing too bad."
    elif not laxed_up:
        "I clearly didn't need the laxitive."
    "I double-check the shower and closet, just to make sure I'm alone."

    "I look at the ceiling. There have to be sensors somewhere."

    "I want to poke around more, but I should probably be seen some more."

    "Wait, the song is talking about pooping in {i}seven{/i} toilets?"
    jump livingroom_harrassment

label livingroom_harrassment:
    scene living_room1
    show steven neutral at left:
        yoffset 250
    show bob neutral at right:
        yoffset 250
    with fade
    $ play_music(Out_of_Earshot)
    b "Hey! Steven! This song's dedicated to you!"
    b "Haha! You know, because of earlier!"

    # show dee neutral at center:
    #     yoffset 250

    "I fantasized about the song I heard in the bathroom. I wondered what it would be like if I went around pooping all over his house."

    "It would be a challenge, but it would have less story."

    "A stealth game? A platformer? Definitely not a visual novel."

    b "That didn't get a raise out of you at all? You're no fun."

    b "If you're just going to daydream, you can go home any time."

    s_nvl "I think I disappointed my boss."
    s_nvl "A slight disappointment that doesn't get me fired totally works for me."

    $ play_music(Life_is_Full_of_Poop)
    $ achievement.grant("Winner! Kept the job!")
    nar_nvl "Good ending: Still employed!"

    jump credits



label credits:

    # End Credits

    ## We hide the quickmenu for the End Credits so they don't appear at the bottom.
    $ quick_menu = False

    ## We hide the textbox as well so it doesn't mess with things
    window hide

    scene black with fade

    ## Find "End Credits Scroll" in extras.rpy to change text.
    call screen credits

    $ persistent.credits_seen = True

    scene black
    with fade

    # Players can skip the credits in subsequent playthroughs of the game.
    label skip_credits:

        pass

    ## We re-enable the quickscreen as the credits are over.

    $ quick_menu = True

    ## Makes [result] work. This needs to be near the end of the game
    ## for it to work properly.
    $ percent()

    ## We display a screen that shows how much the player has seen and played of the game.
    show screen results

    centered "Fin"

    hide screen results

    if persistent.game_clear:

        show text "{size=60}{color=#ffffff}Seriously, thank you for playing!{/color}{/s}":
            xalign 0.5 yalign 0.5 alpha 0.0
            linear 1.0 alpha 1.0

    else:

        if readtotal == 100:

            $ achievement.grant("Completionist")

            show text "{size=60}{color=#ffffff}You are awesome. Thank you for playing!{/color}{/s}":
                xalign 0.5 yalign 0.5 alpha 0.0
                linear 1.0 alpha 1.0

            $ persistent.game_clear = True

            ## The game will show our text displayable so the player can read it
            ## And only continue when there is input
            pause

    # This ends the game.
    return
